<!--
    Derived from Conformance1-5.xsl. Copyright (c) 2001, 2006 Rick Jelliffe and Academia Sinica Computing Center, Taiwan
-->

<!-- The command-line parameters are:
    phase           NMTOKEN | "#ALL" (default) Select the phase for validation
    allow-foreign   "true" | "false" (default)   Pass non-Schematron elements to the generated stylesheet
    diagnose= true | false|yes|no    Add the diagnostics to the assertion test in reports (yes|no are obsolete)
    generate-paths=true|false|yes|no   generate the @location attribute with XPaths (yes|no are obsolete)
    sch.exslt.imports semi-colon delimited string of filenames for some EXSLT implementations    
    optimize        "visit-no-attributes"     Use only when the schema has no attributes as the context nodes
    generate-fired-rule "true"(default) | "false"  Generate fired-rule elements
-->

<xsl:stylesheet
    version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
    xmlns:iso="http://purl.oclc.org/dsdl/schematron"
    xmlns:i="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:isns="http://www.ato.gov.au/IS/2009/02"
    xmlns:tns="http://sbr.gov.au/comn/sbdm.02.data"
    >

    <xsl:import href="iso_schematron_skeleton_for_saxon.xsl"/>

    <xsl:param name="diagnose" >true</xsl:param>
    <xsl:param name="phase" >
        <xsl:choose>
            <!-- Handle ISO Schematron phases -->
            <xsl:when test="//iso:schema/@defaultPhase">
                <xsl:value-of select="//iso:schema/@defaultPhase"/>
            </xsl:when>
            <xsl:otherwise>#ALL</xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="allow-foreign" >false</xsl:param>
    <xsl:param name="generate-paths" >true</xsl:param>
    <xsl:param name="generate-fired-rule" >true</xsl:param>
    <xsl:param name="optimize"/>
    <xsl:param name="output-encoding" ></xsl:param>
    <!-- e.g. saxon file.xml file.xsl "sch.exslt.imports=.../string.xsl;.../math.xsl" -->
    <xsl:param name="sch.exslt.imports" />

    <!-- ================================================================ -->

    <xsl:template name="process-prolog">
        <axsl:import href="CGLS2016FunctionLibrary.xsl"/>
        <axsl:variable name="document-uri">
            <axsl:value-of select="document-uri(/)" />
        </axsl:variable>
        <!-- Variable to support the use of an apostrophe in country names. -->
        <xsl:text disable-output-escaping="yes">&lt;xsl:variable name="Apostrophe"&gt;&#39;&lt;/xsl:variable&gt;</xsl:text>
        <axsl:output method="xml" omit-xml-declaration="no" standalone="yes" indent="no">
            <xsl:if test=" string-length($output-encoding) &gt; 0">
                <xsl:attribute name="encoding">
                    <xsl:value-of select=" $output-encoding" />
                </xsl:attribute>
            </xsl:if>
        </axsl:output>
        <axsl:param name="full-event">false</axsl:param>
    <axsl:param name="document-sequence-number">1</axsl:param>


    </xsl:template>

    <!-- ================================================================ -->

    <!-- Overrides skeleton.xsl -->
    <xsl:template name="process-root">
        <xsl:param name="title"/>
        <xsl:param name="contents" />
        <xsl:param name="queryBinding" >xslt1</xsl:param>
        <xsl:param name="schemaVersion" />
        <xsl:param name="id" />
        <xsl:param name="version"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
        <axsl:variable name="results">
         <xsl:apply-templates mode="do-schema-p"/>
         <xsl:copy-of select="$contents"/>
    </axsl:variable>
    <axsl:if test="$results">
        <axsl:choose>
           <axsl:when test="$full-event='true'">
                <axsl:element name="tns:MessageEvent" namespace="http://sbr.gov.au/comn/sbdm.02.data" inherit-namespaces="no">
                    <axsl:element name="tns:Message.Event.MaximumSeverity.Code">
                        <axsl:choose>
                            <axsl:when test="$results//tns:Message.Event.Item.Severity.Code[.='Error']">Error</axsl:when>
                            <axsl:when test="$results//tns:Message.Event.Item.Severity.Code[.='Warning']">Warning</axsl:when>
                            <axsl:otherwise>Information</axsl:otherwise>
                        </axsl:choose>
                    </axsl:element>
                    <axsl:element name="tns:MessageEventItems">
                        <axsl:copy-of select="$results"/>
                    </axsl:element>
                </axsl:element>
            </axsl:when>
           <axsl:otherwise>
                <axsl:element name="tns:MessageEventItems">
                   <axsl:copy-of select="$results"/>
                </axsl:element>
           </axsl:otherwise>
        </axsl:choose>
    </axsl:if>

    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-assert">
        <xsl:param name="test"/>
        <xsl:param name="diagnostics" />
        <xsl:param name="id" />
        <xsl:param name="flag" />
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
        <xsl:choose>
            <xsl:when test="$diagnose">
                <xsl:call-template name="diagnosticsSplit">
                    <xsl:with-param name="str" select="$diagnostics"/>
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-report">
        <xsl:param name="id"/>
        <xsl:param name="test"/>
        <xsl:param name="diagnostics"/>
        <xsl:param name="flag" />
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-diagnostic">
        <xsl:param name="id"/>
        <!-- Rich parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
            <tns:MessageEventItem>
           <tns:Message.Event.Item.Error.Code>
                <xsl:value-of select="isns:ProcessMessage/isns:Code/text()" />
            </tns:Message.Event.Item.Error.Code>

            <xsl:choose>
                <xsl:when test="string-length(isns:ProcessMessage/isns:Severity/text()) &gt; 0">
                    <tns:Message.Event.Item.Severity.Code>
                        <xsl:value-of select="isns:ProcessMessage/isns:Severity/text()" />
                    </tns:Message.Event.Item.Severity.Code>
                </xsl:when>
                <xsl:otherwise>
                    <tns:Message.Event.Item.Severity.Code>Error</tns:Message.Event.Item.Severity.Code>
                </xsl:otherwise>
            </xsl:choose>

            <xsl:if test="string-length(isns:ProcessMessage/isns:Description/text()) &gt; 0">
                <tns:Message.Event.Item.Short.Description>
                    <xsl:value-of select="isns:ProcessMessage/isns:Description/text()" />
                </tns:Message.Event.Item.Short.Description>
            </xsl:if>

            <xsl:if test="string-length(isns:ProcessMessage/isns:LongDescription/text()) &gt; 0">
                <tns:Message.Event.Item.Detailed.Description>
                    <xsl:value-of select="isns:ProcessMessage/isns:LongDescription/text()" />
                </tns:Message.Event.Item.Detailed.Description>
            </xsl:if>

            <tns:Parameters>
                <xsl:for-each select="isns:ProcessMessage/isns:Parameters/isns:Parameter">
                    <tns:Parameter>
                        <tns:Message.Event.Item.Parameter.Identifier>
                            <xsl:value-of select="isns:Name/text()" />
                        </tns:Message.Event.Item.Parameter.Identifier>
                        <tns:Message.Event.Item.Parameter.Text>
                            <xsl:copy-of select ="isns:Value/node()"/>
                        </tns:Message.Event.Item.Parameter.Text>
                    </tns:Parameter>
                </xsl:for-each>
            </tns:Parameters>

            <tns:Locations>
                <tns:Location>
                    <tns:BusinessDocument.Sequence.Number>
                        <axsl:value-of select="$document-sequence-number"/>
                    </tns:BusinessDocument.Sequence.Number>
                    <tns:Message.Event.Item.Location.Path.Text>
                       <xsl:if test="string-length( isns:ProcessMessage/isns:Location ) &gt; 0">
                           <xsl:copy-of select="isns:ProcessMessage/isns:Location/node()" />
                       </xsl:if>
                    </tns:Message.Event.Item.Location.Path.Text>
                </tns:Location>
            </tns:Locations>

        </tns:MessageEventItem>

    </xsl:template>

    <!-- ================================================================ -->

    <!-- Overrides skeleton -->
    <xsl:template name="process-emph" >
        <xsl:param name="class" />
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-rule">
        <xsl:param name="id"/>
        <xsl:param name="context"/>
        <xsl:param name="flag"/>
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-ns">
        <xsl:param name="prefix"/>
        <xsl:param name="uri"/>
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-p">
        <xsl:param name="icon"/>
        <xsl:param name="class"/>
        <xsl:param name="id"/>
        <xsl:param name="lang"/>
    </xsl:template>

    <!-- ================================================================ -->

    <xsl:template name="process-pattern">
        <xsl:param name="name"/>
        <xsl:param name="id"/>
        <xsl:param name="is-a"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <!-- ================================================================ -->

    <!-- Overrides skeleton -->
    <xsl:template name="process-message" >
        <xsl:param name="pattern"/>
        <xsl:param name="role"/>
    </xsl:template>

    <!-- ================================================================ -->

    <!-- Overrides skeleton -->
    <xsl:template name="process-span" >
        <xsl:param name="class" />
    </xsl:template>

    <!-- ================================================================ -->


</xsl:stylesheet>
