﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
    xmlns:isoold="http://www.ascc.net/xml/schematron"
    xmlns:iso="http://purl.oclc.org/dsdl/schematron"
    xmlns:xhtml="http://www.w3.org/1999/xhtml"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:fn="http://www.w3.org/2005/xpath-functions"
    xmlns:tns="http://www.ato.gov.au/schemas"
    xmlns:regexp="http://www.blah.com"
    xmlns:function="http://ato.gov.au/SWSFunctions"
    version="2.0"
	>

  <!--xmlns:regexp="http://www.blah.com"
    xmlns:fn="http://www.w3.org/2005/xpath-functions"-->

  <!-- ========================================================================
         function : IsDate 
		 ========================================================================
		 Description																																
		   Thsi function make sure data a string can convert to date
		 ========================================================================																						
	     Input Parameters			
			 Input Parameters			
			Date1
			<xsl:param name="Date1" as="xs:anyAtomicType"/>
		 ========================================================================
    	 Output 																																	
	 	    true if input can cast to date , false otherwise
		 ======================================================================== -->

  <xsl:function name="function:IsDate" as="xs:boolean">
    <xsl:param name="Date1" as="xs:anyAtomicType"/>
    <xsl:variable name="is-datecast" as="xs:boolean"
             select="$Date1 castable as xs:date"/>
    <xsl:sequence select= "$is-datecast"/>
  </xsl:function>

  <xsl:function name="function:DatetoSwsStr" as="xs:string">
    <xsl:param name="dateToconvert" as="xs:date"/>
    <xsl:sequence select= "format-date($dateToconvert, '[Y0001]-[M01]-[D01]')"/>
  </xsl:function>


  <!-- ========================================================================
         function : IsDate1GreaterOrEqualToDate2
		 ========================================================================
		 Description																																
		   This function compare Date1 and Date2
		 ========================================================================																						
	     Input Parameters			
			 Input Parameters			
			 Date1, Date2
			 <xsl:param name="Date1" as="xs:anyAtomicType"/>
              <xsl:param name="Date2" as="xs:anyAtomicType"/> 
		 ========================================================================
    	 Output : True 
         If Date1 and Date2 are Date
         and Date1>=Date2
         Otherwise out put false
	 	   
		 ======================================================================== -->
  <xsl:function name="function:IsDate1GreaterOrEqualToDate2" as="xs:boolean">
      <xsl:param name="Date1" as="xs:anyAtomicType"/>
      <xsl:param name="Date2" as="xs:anyAtomicType"/>
      <xsl:choose>
      <xsl:when test="function:IsDate($Date1) and function:IsDate($Date2)">
        <xsl:variable name="castedDate1" select="xs:date($Date1)" as="xs:date"/>
        <xsl:variable name="castedDate2" select="xs:date($Date2)" as="xs:date"/>
        <xsl:sequence select= "$castedDate1 >= $castedDate2"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- ========================================================================
         function : IsDate1GreaterThanDate2
		 ========================================================================
		 Description																																
		   This function compare Date1 and Date2
		 ========================================================================																						
	     Input Parameters			
			 Input Parameters			
			 Date1, Date2
			 <xsl:param name="Date1" as="xs:anyAtomicType"/>
              <xsl:param name="Date2" as="xs:anyAtomicType"/> 
		 ========================================================================
    	 Output : True 
         If Date1 and Date2 are Date
         and Date1>Date2
         Otherwise output false
	 	   
		 ======================================================================== -->

  <xsl:function name="function:IsDate1GreaterThanDate2" as="xs:boolean">
      <xsl:param name="Date1" as="xs:anyAtomicType"/>
      <xsl:param name="Date2" as="xs:anyAtomicType"/>
      <xsl:choose>
      <xsl:when test="function:IsDate($Date1) and function:IsDate($Date2)">
        <xsl:variable name="castedDate1" select="xs:date($Date1)" as="xs:date"/>
        <xsl:variable name="castedDate2" select="xs:date($Date2)" as="xs:date"/>
        <xsl:sequence select= "$castedDate1 > $castedDate2"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- ========================================================================
         function : ValidateTAN
		 ========================================================================
		 Description																																
		   This function validates Tax Agent Number
            weighingFactors = {7,9,8,4,6,3,5,1};
            SumTANWSum = Sum  (Digig[i] * weightingFactors i
		 ========================================================================																						
	     Input Parameters			
			 Input Parameters			
		      TAN_Initial
			<xsl:param name="TAN_Initial" as="xs:anyAtomicType"/>
		 ========================================================================
    	 Output : True 
        If TAN_Initial.length =8 and   ($SumTANWSum mod 11 ) = 0   
        else return false         
           
		 ======================================================================== -->

  <xsl:function name="function:ValidateTAN" as="xs:boolean">
    <xsl:param name="TAN_Initial" as="xs:anyAtomicType"/>
    <xsl:choose>
      <xsl:when test="string-length($TAN_Initial) > 0">
        <xsl:variable name="TANNoSpace" select="translate($TAN_Initial,' ','')" as="xs:string"/>
        <xsl:variable name="TANNumberString" select=" string(number($TANNoSpace))" as="xs:string"/>
        <xsl:variable name="TANlength" select="string-length($TANNoSpace)" as="xs:integer"/>
        <xsl:variable name="TANWSum1" select=" 7*number(substring($TANNoSpace,1,1))" as="xs:double"/>
        <xsl:variable name="TANWSum2" select="9*number(substring($TANNoSpace,2,1)) " as="xs:double"/>
        <xsl:variable name="TANWSum3" select="8*number(substring($TANNoSpace,3,1))" as="xs:double"/>
        <xsl:variable name="TANWSum4" select="4*number(substring($TANNoSpace,4,1))" as="xs:double"/>
        <xsl:variable name="TANWSum5" select="6*number(substring($TANNoSpace,5,1))" as="xs:double"/>
        <xsl:variable name="TANWSum6" select="3*number(substring($TANNoSpace,6,1))" as="xs:double"/>
        <xsl:variable name="TANWSum7" select="5*number(substring($TANNoSpace,7,1)) " as="xs:double"/>
        <xsl:variable name="TANWSum8" select="1*number(substring($TANNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="SumTANWSum" select="$TANWSum1 + $TANWSum2 + $TANWSum3 + $TANWSum4 + $TANWSum5 + $TANWSum6 + $TANWSum7 + $TANWSum8" as="xs:double"/>
        <xsl:choose>
          <xsl:when test="($TANlength = 8) and ($SumTANWSum mod 11 ) = 0">
            <xsl:value-of  select= "true()"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select= "false()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!--ABN weighingFactors = { 10, 1, 3, 5, 7, 9, 11, 13, 15, 17, 19 };-->
  <xsl:function name="function:ValidateABN" as="xs:boolean">
    <xsl:param name="ABN_Initial" as="xs:anyAtomicType"/>
    <xsl:choose>
      <xsl:when test="string-length($ABN_Initial) > 0">
        <xsl:variable name="ABNNoSpace" select="translate($ABN_Initial,' ','')" as="xs:string"/>
        <xsl:variable name="ABNNumbeString" select=" string(number($ABNNoSpace))" as="xs:string"/>
        <xsl:variable name="ABNlength" select="string-length($ABNNoSpace)" as="xs:double"/>
        <xsl:variable name="ABNWSum1" select="10*(number(substring($ABNNoSpace,1,1))-1) " as="xs:double"/>
        <xsl:variable name="ABNWSum2" select="1*number(substring($ABNNoSpace,2,1)) " as="xs:double"/>
        <xsl:variable name="ABNWSum3" select="3*number(substring($ABNNoSpace,3,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum4" select="5*number(substring($ABNNoSpace,4,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum5" select=" 7*number(substring($ABNNoSpace,5,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum6" select=" 9*number(substring($ABNNoSpace,6,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum7" select="11*number(substring($ABNNoSpace,7,1)) " as="xs:double"/>
        <xsl:variable name="ABNWSum8" select="13*number(substring($ABNNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum9" select=" 15*number(substring($ABNNoSpace,9,1))" as="xs:double"/>
        <xsl:variable name="ABNWSum10" select="17*number(substring($ABNNoSpace,10,1)) " as="xs:double"/>
        <xsl:variable name="ABNWSum11" select="19*number(substring($ABNNoSpace,11,1))" as="xs:double"/>
        <xsl:variable name="SumABNWSum" select="$ABNWSum1 + $ABNWSum2 + $ABNWSum3 + $ABNWSum4 + $ABNWSum5 + $ABNWSum6 + $ABNWSum7 + $ABNWSum8 + $ABNWSum9 + $ABNWSum10 + $ABNWSum11" as="xs:double"/>
        <xsl:choose>
          <xsl:when test=" ($ABNlength = 11 ) and ($SumABNWSum mod 89 ) = 0 ">
            <xsl:value-of   select= "true()"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select= "false()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!--int checkDigit = Int32.Parse(cleanACN[8].ToString());
        ACN weighingFactors = { 8, 7, 6, 5, 4, 3, 2, 1 };
        int remainder = weightedSum % 10;
        return checkDigit == (10 - remainder) % 10;-->
  <xsl:function name="function:ValidateACN" as="xs:boolean">
    <xsl:param name="ACN_Initial" as="xs:anyAtomicType"/>
    <xsl:choose>
      <xsl:when test="string-length($ACN_Initial) > 0">
        <xsl:variable name="ACNNoSpace" select="translate($ACN_Initial,' ','')" as="xs:string"/>
        <xsl:variable name="ACNNumberString" select=" string(number($ACNNoSpace))" as="xs:string"/>
        <xsl:variable name="ACNLength" select="string-length($ACNNoSpace)" as="xs:double"/>
        <xsl:variable name="ACNWSum1" select="8*number(substring($ACNNoSpace,1,1)) " as="xs:double"/>
        <xsl:variable name="ACNWSum2" select="7*number(substring($ACNNoSpace,2,1))" as="xs:double"/>
        <xsl:variable name="ACNWSum3" select="6*number(substring($ACNNoSpace,3,1))" as="xs:double"/>
        <xsl:variable name="ACNWSum4" select="5*number(substring($ACNNoSpace,4,1))" as="xs:double"/>
        <xsl:variable name="ACNWSum5" select=" 4*number(substring($ACNNoSpace,5,1))" as="xs:double"/>
        <xsl:variable name="ACNWSum6" select="3*number(substring($ACNNoSpace,6,1)) " as="xs:double"/>
        <xsl:variable name="ACNWSum7" select="2*number(substring($ACNNoSpace,7,1))" as="xs:double"/>
        <xsl:variable name="ACNWSum8" select="1*number(substring($ACNNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="ACNcheckDigit" select="number(substring($ACNNoSpace,9,1))" as="xs:double"/>
        <xsl:variable name="SumACNWSum" select=" $ACNWSum1 + $ACNWSum2 + $ACNWSum3 + $ACNWSum4 + $ACNWSum5 + $ACNWSum6 + $ACNWSum7 + $ACNWSum8 " as="xs:double"/>
        <xsl:variable name="ACNremainder" select="$SumACNWSum mod 10 " as="xs:double"/>
        <xsl:choose>
          <xsl:when test=" ($ACNLength = 9) and ((10-$ACNremainder ) mod 10) = $ACNcheckDigit ">
            <xsl:value-of   select= "true()"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select= "false()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!--TFN weighingFactors = { 1, 4, 3, 7, 5, 8, 6, 9, 10 };-->


  <xsl:function name="function:ValidateTFN" as="xs:boolean">
    <xsl:param name="TFN_Initial" as="xs:anyAtomicType"/>
    <xsl:choose>
      <xsl:when test="string-length($TFN_Initial) > 0">
        <xsl:variable name="TFNNoSpace" select="translate($TFN_Initial,' ','')" as="xs:string"/>
        <xsl:variable name="TFNNumberString" select=" string(number($TFNNoSpace))" as="xs:string"/>
        <xsl:variable name="TFNlength" select="string-length($TFNNoSpace)" as="xs:double"/>
        <xsl:variable name="TFNWSum1" select="1*number(substring($TFNNoSpace,1,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum2" select="4*number(substring($TFNNoSpace,2,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum3" select="3*number(substring($TFNNoSpace,3,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum4" select="7*number(substring($TFNNoSpace,4,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum5" select="5*number(substring($TFNNoSpace,5,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum6" select="8*number(substring($TFNNoSpace,6,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum7" select="6*number(substring($TFNNoSpace,7,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum8" select="9*number(substring($TFNNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="TFNWSum9" select="10*number(substring($TFNNoSpace,9,1))" as="xs:double"/>
        <xsl:variable name="TFNLg8WSum8" select="0" as="xs:double"/>
        <xsl:variable name="TFNLg8WSum9" select="10*number(substring($TFNNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="TFNLg8WSum8" select="0" as="xs:double"/>
        <xsl:variable name="TFNLg8WSum9" select="10*number(substring($TFNNoSpace,8,1))" as="xs:double"/>
        <xsl:variable name="SumTFNLg8WSum" select="$TFNWSum1 + $TFNWSum2 + $TFNWSum3 + $TFNWSum4 + $TFNWSum5 + $TFNWSum6 + $TFNWSum7 + $TFNLg8WSum8 +$TFNLg8WSum9" as="xs:double"/>
        <xsl:variable name="SumTFNLg9WSum" select=" $TFNWSum1 + $TFNWSum2 + $TFNWSum3 + $TFNWSum4 + $TFNWSum5 + $TFNWSum6 + $TFNWSum7 + $TFNWSum8 +$TFNWSum9" as="xs:double"/>
        <xsl:choose>
          <xsl:when test=" ($TFNlength = 9 and ($SumTFNLg9WSum mod 11)=0 ) or ($TFNlength = 8 and ($SumTFNLg8WSum mod 11)=0 ) ">
            <xsl:value-of   select= "true()"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select= "false()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select="false()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- ========================================================================
         function : GetCurrentFBTYear
		 ========================================================================
		 Description																																
		   This function get Current  FBT year
		 ========================================================================																						
	    Input Parameters			
			
		 ========================================================================
    	 Output : FBT Year
          	   
		 ======================================================================== -->

  <xsl:function name="function:GetCurrentFBTYear" as="xs:integer">
    <xsl:sequence select= "function:GetFBTYear(current-date())"/>
  </xsl:function>

  <!-- ========================================================================
         function : GetFBTYear
		 ========================================================================
		 Description																																
		   This function get FBT year
		 ========================================================================																						
	    Input Parameters			
			 Input Parameters			
			 Date1 as Date or string: anyAtomicType
			  <xsl:param name="Date1" as="xs:anyAtomicType"/>
		 ========================================================================
    	 Output : FBT Year
         If para pass in as a date -> Return FBTYear( If Month >3 then FBT Yr= Ry+1) else FBTYr=Year 
         If Para pass in  not a Date -> Return FBT Year =0
	 	   
		 ======================================================================== -->


  <xsl:function name="function:GetFBTYear" as="xs:integer">
    <xsl:param name="Date1" as="xs:anyAtomicType"/>
    <xsl:variable name="fbtYear" select="0" as="xs:integer"/>
    <xsl:choose>
      <xsl:when test="function:IsDate($Date1) ">
        <xsl:variable name="castedDate1" select="xs:date($Date1)" as="xs:date"/>
        <xsl:sequence select="function:GetFBTYearFromDate($castedDate1)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select= "$fbtYear"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- ========================================================================
         function : GetFBTYearFromDate
		 ========================================================================
		 Description																																
		   This function get FBT year
		 ========================================================================																						
	    Input Parameters			
			 Input Parameters			
			 Date1 as Date 
			  <xsl:param name="Date1" as="xs:date"/>
		 ========================================================================
    	 Output : FBT Year
         If para pass in as a date -> Return FBTYear( If Month >3 then FBT Yr= Ry+1) else FBTYr=Year 
         	   
		 ========================================================================
         -->

  <xsl:function name="function:GetFBTYearFromDate" as="xs:integer">
    <xsl:param name="Date1" as="xs:anyAtomicType"/>
    <xsl:variable name="fbtYear" select="0" as="xs:integer"/>
    <xsl:choose>
      <xsl:when test="function:IsDate($Date1) ">
        <xsl:variable name="datecast" as="xs:date"
             select="$Date1 cast as xs:date"/>
        <xsl:variable name="lyear" select="year-from-date($datecast)" as="xs:integer"/>
        <xsl:variable name="lmonth" select="month-from-date($datecast)" as="xs:integer"/>
        <xsl:choose>
          <xsl:when test=" $lmonth &gt; 3 ">
            <xsl:sequence select="$lyear+1"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:sequence select= "$lyear"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select= "$fbtYear"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- ========================================================================
         function : DateToFinancialYear
		 ========================================================================
		 Description																																
		   This function get Financial Year , by default financial year start at July 
		 ========================================================================																						
	    Input Parameters			
			 Input Parameters			
			 Date1 as Date 
			  <xsl:param name="Date1" as="xs:date"/>
		 ========================================================================
    	 Output : Financial Year
         If para pass in as a date -> Return Financial Year( If Month <7 then FinancialYr= Yr) else FBTYr=Year+1 
         	   
		 ========================================================================
        -->

  <xsl:function name="function:DateToFinancialYear" as="xs:integer">
      <xsl:param name="Date1" as="xs:anyAtomicType"/>
    <xsl:choose>
      <xsl:when test="function:IsDate($Date1) ">
        <xsl:sequence select= "function:DateToFinancialYear($Date1,7)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select= "0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>


  <!-- ========================================================================
         function : DateToFinancialYear
		 ========================================================================
		 Description																																
		   This function get Financial Year , by default financial year start at July 
		 ========================================================================																						
	    Input Parameters			
			 Input Parameters			
			 Date1 as Date 
			  <xsl:param name="Date1" as="xs:date"/>
             financialYearStartMonth
             <xsl:param name="financialYearStartMonth" as="xs:integer"/>
		 ========================================================================
    	 Output : Financial Year
         If para pass in as a date  and int-> Return Financial Year( If dateMonth <financialYearStartMonth then FinancialYr= Yr) else FBTYr=Year+1 
         	   
		 ========================================================================
        -->

  <xsl:function name="function:DateToFinancialYear" as="xs:integer">
      <xsl:param name="Date1" as="xs:anyAtomicType"/>
    <xsl:param name="financialYearStartMonth" as="xs:integer"/>
    <xsl:choose>
      <xsl:when test="function:IsDate($Date1) ">
        <xsl:variable name="datecast" as="xs:date"
             select="$Date1 cast as xs:date"/>
        <xsl:variable name="lyearOfdate" select="year-from-date($datecast)" as="xs:integer"/>
        <xsl:variable name="lmonthOfdate" select="month-from-date($datecast)" as="xs:integer"/>
        <xsl:choose>
          <xsl:when test="$financialYearStartMonth &gt; $lmonthOfdate ">
            <xsl:sequence select="$lyearOfdate"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:sequence select= "$lyearOfdate+1"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:sequence select= "0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>




</xsl:stylesheet>
